@@ -10,7 +10,7 @@ function(x,order.by,dateFormat="POSIXct",frequency=NULL,...) {
   # Should allow 'order.by' to be a vector of dates or a scaler
   # representing the column number to use.
   if(missing(order.by)) # added '...' args to allow for tz specification
-    order.by <- do.call(paste('as',dateFormat,sep='.'),list(rownames(x),...))
+    order.by <- do.call(paste('as',dateFormat,sep='.'),list(rownames(x)))
   xx <- xts(x,
             order.by=order.by,
             frequency=frequency,
